summaryrefslogtreecommitdiff
path: root/indra/newview/llselectmgr.h
diff options
context:
space:
mode:
authorTodd Stinson <stinson@lindenlab.com>2012-06-21 17:29:12 -0700
committerTodd Stinson <stinson@lindenlab.com>2012-06-21 17:29:12 -0700
commitaea6b0c70ccb1a330c1ee2a0f66c3fa72d2700ca (patch)
tree0c0f3fedcc5caf8972dc00d2163d676edf40992c /indra/newview/llselectmgr.h
parentf86e2891be5a4e55f0ffae685915a92d8514e59a (diff)
PATH-760: Renaming some methods of LLSelectMgr.
Diffstat (limited to 'indra/newview/llselectmgr.h')
-rw-r--r--indra/newview/llselectmgr.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/llselectmgr.h b/indra/newview/llselectmgr.h
index 07eb62a8fa..9787493e43 100644
--- a/indra/newview/llselectmgr.h
+++ b/indra/newview/llselectmgr.h
@@ -560,9 +560,9 @@ public:
BOOL selectGetRootsModify();
BOOL selectGetModify();
- // returns TRUE if is all objects are non-permanent
- BOOL selectGetRootsNonPermanent();
- BOOL selectGetNonPermanent();
+ // returns TRUE if is all objects are non-permanent-enforced
+ BOOL selectGetRootsNonPermanentEnforced();
+ BOOL selectGetNonPermanentEnforced();
// returns TRUE if selected objects can be transferred.
BOOL selectGetRootsTransfer();